getgac: A web scraping function

Description Usage Examples

View source: R/getgac.R

Description

This function allows you to scrape data from Global Affairs Canada softwood lumber Monthly Export Reports (Canada-US)

Usage

1
getgac(year, month)

Examples

1
jan_2018 <- getgac("2018","01")

j-clapper/getgac documentation built on Nov. 4, 2019, 2:14 p.m.