This function allows you to scrape data from Global Affairs Canada softwood lumber Monthly Export Reports (Canada-US)
1 | getgac(year, month)
|
1 | jan_2018 <- getgac("2018","01")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.